==> fengoffice_1.7.5.zip: fengoffice/language/pl_pl/objects.php <==
<?php return array(
	'user' => 'Użytkownik',
	'group' => 'Grupa',
	'groups' => 'Grupy',
	'users' => 'Użytkownicy',
	'member' => 'Członek',
	'members' => 'Członkowie',
	'company' => 'Firma',
	'companies' => 'Firmy',
	'client' => 'Klient',
	'clients' => 'Klienci',
	'package' => 'Pakiet',
	'project' => 'Projekt',
	'projects' => 'Projekty',
	'message' => 'Notatka',
	'messages' => 'Notatki',
	'comment' => 'Komentarz',
	'comments' => 'Komentarze',
	'milestone' => 'Etap',
	'milestones' => 'Etapy',
	'task' => 'Zadanie',
	'subtasks' => 'Zadania podrzędne',
	'tasks' => 'Zadania',
	'task list' => 'Zadanie',
	'task lists' => 'Zadania',
	'tag' => 'Tag',
	'tags' => 'Tagi',
	'attachment' => 'Załącznik',
	'attachments' => 'Załączniki',
	'object subscribers' => 'Subskrybenci',
	'form' => 'Formularz',
	'forms' => 'Formularze',
	'file' => 'Plik',
	'files' => 'Pliki',
	'file revision' => 'Wersja pliku',
	'file revisions' => 'Wersje pliku',
	'file contents' => 'Zawartość pliku',
	'revision' => 'Wersja',
	'revisions' => 'Wersje',
	'folder' => 'Katalog',
	'folders' => 'Katalogi',
	'configuration category' => 'Kategoria konfiguracyjna',
	'configuration categories' => 'Kategorie konfiguracyjne',
	'handin' => 'Doręczenie',
	'handins' => 'Doręczenia',
	'emailunclassified' => 'E-mail',
	'owner company' => 'Firma właścicielska',
	'client companies' => 'Firmy klienckie',
	'open milestone' => 'Otwórz etap',
	'open milestones' => 'Otwarte etapy',
	'completed milestone' => 'Zakończony etap',
	'completed milestones' => 'Zakończone etapy',
	'late milestones' => 'Opóźnione etapy',
	'late milestones and tasks' => 'Opóźnione etapy i zadania',
	'today milestones' => 'Dzisiejsze etapy',
	'upcoming milestones' => 'Nadchodzące etapy',
	'completed task list' => 'Zakończone zadanie',
	'completed task lists' => 'Zakończone zadania',
	'open task list' => 'Otwarte zadanie',
	'open task lists' => 'Otwarte zadania',
	'active project' => 'Aktywny projekt',
	'active projects' => 'Aktywne projekty',
	'finished project' => 'Zamknięty projekt',
	'finished projects' => 'Zamknięte projekty',
	'linked object' => 'Dowiązany obiekt',
	'linked objects' => 'Powiązane elementy',
	'important message' => 'Ważna notatka',
	'important messages' => 'Ważne notatki',
	'important file' => 'Ważny plik',
	'important files' => 'Ważne pliki',
	'parent task' => 'Zadanie nadrzędne',
	'private message' => 'Prywatna notatka',
	'private milestone' => 'Etap prywatny',
	'private task list' => 'Prywatne zadania',
	'private comment' => 'Prywatny komentarz',
	'private file' => 'Prywatny plik',
	'object reminders' => 'Przypomnienia',
	'add object reminder' => 'Dodaj przypomnienie',
	'load file' => 'Załaduj plik',
	'time' => 'Czas',
	'reporting' => 'Raporty',
	'create document' => 'Utwórz dokumenty',
	'create presentation' => 'Utwórz prezentacje',
	'modify object subscribers' => 'Modyfikuj subskrybentów',
	'subscription modified successfully' => 'Subskrybenci zmodyfikowani',
	'urgent milestone' => 'Pilne',
	'the message' => 'wiadomość',
	'the email' => 'e-mail',
	'the emailunclassified' => 'e-mail',
	'the contact' => 'kontakt',
	'the company' => 'firma',
	'the event' => 'wydarzenie',
	'the file' => 'plik',
	'the file revision' => 'wersja pliku',
	'the task' => 'zadanie',
	'the milestone' => 'etap',
	'the webpage' => 'odnośnik',
	'the comment' => 'komentarz',
	'the user' => 'użytkowwnik',
	'the project' => 'projekt',
	'activity add' => '{1} dodano {0} {2}',
	'activity edit' => '{1} wyedytowano {0} {2}',
	'activity delete' => '{1} usunięto {0} {2}',
	'activity trash' => '{1} przeniesiono do kosza {0} {2}',
	'activity untrash' => '{1} przywrócono z kosza {0} {2}',
	'activity open' => '{1} otwarto {0} {2}',
	'activity close' => '{1} zamknięto {0} {2}',
	'activity subscribe' => '{1} zasubskrybował/a {3} do {0} {2}',
	'activity unsubscribe' => '{1} zakończył(a) subskrypcję {3} do {0} {2}',
	'activity tag' => '{1} otagował/a {0} {2} tagami {3}',
	'activity untag' => '{1} usunął/usunęła tagi z {0} {2}',
	'activity comment' => '{1} skomentował/a {0} {2}:<br>    "{3}"',
	'activity link' => '{1} połączył/a {0} {2} z {3} {4}',
	'activity unlink' => '{1} rozłączył/a {0} {2} i {3} {4}',
	'activity login' => '{0} zalogowany/a',
	'activity logout' => '{0} wylogował/a się',
	'activity archive' => '{1} zarchiwizował/a {0} {2}',
	'activity unarchive' => '{1} przywrócił/a z archiwum {0} {2}',
	'activity move from to' => '{1} przesunął/przesunęła {0} {2} z {3} do {4}',
	'activity move from' => '{1} przesunął/przesunęła {0} {2} z {3} ',
	'activity move to' => '{1} przesunął/przesunęła {0} {2} do {3} ',
	'activity move' => '{1} przesunął/przesunęła {0} {2} ',
	'activity copy to' => '{1} skopiował/a {0} {2} do {3} ',
	'activity copy' => '{1} skopiował/a {0} {2}',
	'activity read' => '{1} odczytał/a {0} {2}',
	'activity download' => '{1} pobrał/a {0} {2}',
	'x users' => '{0} użytkowników {1}',
	'the file_revision' => 'rewizja pliku',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/pl_pl/objects.php <==
<?php return array(
	'user' => 'Użytkownik',
	'group' => 'Grupa',
	'groups' => 'Grupy',
	'users' => 'Użytkownicy',
	'member' => 'Członek',
	'members' => 'Członkowie',
	'company' => 'Firma',
	'companies' => 'Firmy',
	'client' => 'Klient',
	'clients' => 'Klienci',
	'package' => 'Pakiet',
	'project' => 'Projekt',
	'projects' => 'Projekty',
	'message' => 'Notatka',
	'messages' => 'Notatki',
	'comment' => 'Komentarz',
	'comments' => 'Komentarze',
	'milestone' => 'Etap',
	'milestones' => 'Etapy',
	'task' => 'Zadanie',
	'subtasks' => 'Zadania podrzędne',
	'tasks' => 'Zadania',
	'task list' => 'Zadanie',
	'task lists' => 'Zadania',
	'tag' => 'Tag',
	'tags' => 'Tagi',
	'attachment' => 'Załącznik',
	'attachments' => 'Załączniki',
	'object subscribers' => 'Subskrybenci',
	'form' => 'Formularz',
	'forms' => 'Formularze',
	'file' => 'Plik',
	'files' => 'Pliki',
	'file revision' => 'Wersja pliku',
	'file revisions' => 'Wersje pliku',
	'file contents' => 'Zawartość pliku',
	'revision' => 'Wersja',
	'revisions' => 'Wersje',
	'folder' => 'Katalog',
	'folders' => 'Katalogi',
	'configuration category' => 'Kategoria konfiguracyjna',
	'configuration categories' => 'Kategorie konfiguracyjne',
	'handin' => 'Doręczenie',
	'handins' => 'Doręczenia',
	'emailunclassified' => 'E-mail',
	'owner company' => 'Firma właścicielska',
	'client companies' => 'Firmy klienckie',
	'open milestone' => 'Otwarty etap',
	'open milestones' => 'Otwarte etapy',
	'completed milestone' => 'Zakończony etap',
	'completed milestones' => 'Zakończone etapy',
	'late milestones' => 'Opóźnione etapy',
	'late milestones and tasks' => 'Opóźnione etapy i zadania',
	'today milestones' => 'Dzisiejsze etapy',
	'upcoming milestones' => 'Nadchodzące etapy',
	'completed task list' => 'Zakończone zadanie',
	'completed task lists' => 'Zakończone zadania',
	'open task list' => 'Otwarte zadanie',
	'open task lists' => 'Otwarte zadania',
	'active project' => 'Aktywny projekt',
	'active projects' => 'Aktywne projekty',
	'finished project' => 'Zamknięty projekt',
	'finished projects' => 'Zamknięte projekty',
	'linked object' => 'Dowiązany obiekt',
	'linked objects' => 'Powiązane elementy',
	'important message' => 'Ważna notatka',
	'important messages' => 'Ważne notatki',
	'important file' => 'Ważny plik',
	'important files' => 'Ważne pliki',
	'parent task' => 'Zadanie nadrzędne',
	'private message' => 'Prywatna notatka',
	'private milestone' => 'Etap prywatny',
	'private task list' => 'Prywatne zadania',
	'private comment' => 'Prywatny komentarz',
	'private file' => 'Prywatny plik',
	'object reminders' => 'Przypomnienia',
	'add object reminder' => 'Dodaj przypomnienie',
	'load file' => 'Załaduj plik',
	'time' => 'Czas',
	'reporting' => 'Raporty',
	'create document' => 'Utwórz dokumenty',
	'create presentation' => 'Utwórz prezentacje',
	'modify object subscribers' => 'Modyfikuj subskrybentów',
	'subscription modified successfully' => 'Subskrybenci zmodyfikowani',
	'urgent milestone' => 'Pilne',
	'the message' => 'wiadomość',
	'the email' => 'e-mail',
	'the emailunclassified' => 'e-mail',
	'the contact' => 'kontakt',
	'the company' => 'firma',
	'the event' => 'wydarzenie',
	'the file' => 'plik',
	'the file revision' => 'wersja pliku',
	'the task' => 'zadanie',
	'the milestone' => 'etap',
	'the webpage' => 'odnośnik',
	'the comment' => 'komentarz',
	'the user' => 'użytkowwnik',
	'the project' => 'projekt',
	'activity add' => '{1} dodano {0} {2}',
	'activity edit' => '{1} wyedytowano {0} {2}',
	'activity delete' => '{1} usunięto {0} {2}',
	'activity trash' => '{1} przeniesiono do kosza {0} {2}',
	'activity untrash' => '{1} przywrócono z kosza {0} {2}',
	'activity open' => '{1} otwarto {0} {2}',
	'activity close' => '{1} zamknięto {0} {2}',
	'activity subscribe' => '{1} zasubskrybował/a {3} do {0} {2}',
	'activity unsubscribe' => '{1} zakończył(a) subskrypcję {3} do {0} {2}',
	'activity tag' => '{1} otagował/a {0} {2} tagami {3}',
	'activity untag' => '{1} usunął/usunęła tagi z {0} {2}',
	'activity comment' => '{1} skomentował/a {0} {2}:<br>    "{3}"',
	'activity link' => '{1} połączył/a {0} {2} z {3} {4}',
	'activity unlink' => '{1} rozłączył/a {0} {2} i {3} {4}',
	'activity login' => '{0} zalogowany/a',
	'activity logout' => '{0} wylogował/a się',
	'activity archive' => '{1} zarchiwizował/a {0} {2}',
	'activity unarchive' => '{1} przywrócił/a z archiwum {0} {2}',
	'activity move from to' => '{1} przesunął/przesunęła {0} {2} z {3} do {4}',
	'activity move from' => '{1} przesunął/przesunęła {0} {2} z {3} ',
	'activity move to' => '{1} przesunął/przesunęła {0} {2} do {3} ',
	'activity move' => '{1} przesunął/przesunęła {0} {2} ',
	'activity copy to' => '{1} skopiował/a {0} {2} do {3} ',
	'activity copy' => '{1} skopiował/a {0} {2}',
	'activity read' => '{1} odczytał/a {0} {2}',
	'activity download' => '{1} pobrał/a {0} {2}',
	'x users' => '{0} użytkowników {1}',
); ?>
